@@ -20,7 +20,9 @@ cli_logger = get_logger(__name__, LOG_FILEPATH="/tmp/sumoapptestutils.log", LOG_
 if six.PY2:
     input = raw_input
 
-APP_CATEGORIES = ["Amazon Web Services", "Compliance and Security", "Database", "DevOps", "Google Cloud Platform", "IT Infrastructure", "Kubernetes", "Microsoft Azure", "Operating System", "Storage", "Sumo Logic", "Web Server", "Work from Home Solution"]
+APP_CATEGORIES = ["Amazon Web Services", "Compliance and Security", "Database", "DevOps", "Google Cloud Platform",
+                  "IT Infrastructure", "Kubernetes", "Microsoft Azure", "Operating System", "Storage", "Sumo Logic",
+                  "Web Server", "Work from Home Solution", "Sumo Logic Certified"]
 
 reverse_category_map = {val: i for i, val in enumerate(APP_CATEGORIES)}
 
@@ -166,7 +168,8 @@ class BaseSubstitutionStrategy(object):
     @classmethod
     def _process_dashboard_queries(cls, dash, callback):
         if TestApp.is_mew_board(dash):
-            for panel in dash["rootPanel"]["panels"]:
+            panels = dash["rootPanel"].get("panels", []) if dash.get("rootPanel") else dash.get("panels", [])
+            for panel in panels:
                 if panel.get("panelType") == "TextPanel" or panel.get("Type") == "TextPanel":
                     continue
                 for query in panel["queries"]:
@@ -175,7 +178,10 @@ class BaseSubstitutionStrategy(object):
                         query["queryString"] = callback(query["queryString"], "Panel: %s" % panel_name, "Logs")
                     else:
                         query["queryString"] = callback(query["queryString"], "Panel: %s" % panel_name, "Metrics")
-            for variable in dash["rootPanel"].get("variables", []):
+
+            variables = dash["rootPanel"].get("variables", []) if dash.get("rootPanel") else dash.get("variables", [])
+
+            for variable in variables:
                 if variable.get("sourceDefinition", {}).get("variableSourceType", "") == "LogQueryVariableSourceDefinition":
                     variable["sourceDefinition"]["query"] = callback(variable["sourceDefinition"]["query"], "Variable: %s" % variable["name"], "Logs")
                 elif variable.get("sourceDefinition", {}).get("variableSourceType", "") == "MetricQueryVariableSourceDefinition":
@@ -204,7 +210,7 @@ class BaseSubstitutionStrategy(object):
     @classmethod
     def process_queries(cls, folder, callback):
         for dash in folder["children"]:
-            if dash["type"] in ("Report", "Dashboard", "DashboardSyncDefinition", "MewboardSyncDefinition"):
+            if dash["type"] in ("Report", "Dashboard", "DashboardSyncDefinition", "MewboardSyncDefinition", "DashboardV2SyncDefinition"):
                 cls._process_dashboard_queries(dash, callback)
             elif dash["type"] in ("Search", "SavedSearchWithScheduleSyncDefinition"):
                 cls._processs_saved_search_queries(dash, callback)
@@ -248,7 +254,7 @@ class WholePrefixParameterSubstitutionMixin(BaseSubstitutionStrategy):
 
         with_sc = self._get_substition_expressions(query_string, self.source_category_regex)
         for expr in with_sc:
-            unique_expr = expr.replace("\s*","").lower()
+            unique_expr = expr.replace("\s*", "").lower()
             if expr in self.reverse_param_mapping:
                 param_name = self.reverse_param_mapping[expr]
                 query_string = re.sub(expr, "$$%s " % param_name, query_string, flags=re.IGNORECASE)
@@ -268,9 +274,6 @@ class WholePrefixParameterSubstitutionMixin(BaseSubstitutionStrategy):
             self.appended_params.add(param_name)
 
         # existing params
-
-
-
         return query_string
 
     def set_source_parameters(self):
@@ -316,6 +319,8 @@ class WholePrefixParameterSubstitutionMixin(BaseSubstitutionStrategy):
 
 class AppManifest(WholePrefixParameterSubstitutionMixin):
 
+    MANDATORY_CATEGORY_FOR_PARTNER_APPS = "Sumo Logic Certified"
+
     def __init__(self, filepath, categories, author, help_url):
         super(AppManifest, self).__init__()
         # cfg = Config()
@@ -328,6 +333,8 @@ class AppManifest(WholePrefixParameterSubstitutionMixin):
         self.sourceFilePath = filepath
         self.app_config_key = get_app_config_key(filepath)
         self.categories = categories
+        if USER.is_partner and self.MANDATORY_CATEGORY_FOR_PARTNER_APPS not in self.categories:
+            self.categories.append(self.MANDATORY_CATEGORY_FOR_PARTNER_APPS)
         self.appDict = json.loads(self.appjson)
         dashboard_class = get_test_class(appjson=self.appDict)
         dashboards, searches = dashboard_class.get_content(self.appDict)
