@@ -9,7 +9,8 @@ from PIL import Image
 from functools import reduce
 from abc import abstractmethod, ABCMeta
 from sumoappclient.omnistorage.factory import ProviderFactory
-from sumoapputils.common.utils import EXCLUDED_APPS_WITHOUT_SC_PARAMS, get_test_logger
+from sumoapputils.common.utils import EXCLUDED_APPS_WITHOUT_SC_PARAMS, get_test_logger, slugify
+
 
 try:
     from sumoapputils.appdev.appdeployapi import push_app_api, push_app_api_v2
@@ -25,6 +26,7 @@ class TestApp(unittest.TestCase):
     COMMUNITY_URL = "https://support.sumologic.com/hc/en-us/community/topics/200263058-Applications-and-Integrations"
     MAX_FILE_SIZE = 5*1000*1000
     CUMULATIVE_MAX_FILE_SIZE = 100*1000*1000
+    datetime_terms = ["week", "previous_week", "month", "previous_month", "relative", "RelativeTimeRangeBoundary", "yesterday", "today"]
 
     def __init__(self, manifestfile, appfile, deployment_name,
                  access_id, access_key, *args, **kwargs):
@@ -46,7 +48,7 @@ class TestApp(unittest.TestCase):
             self.app_description = self.manifestjson["description"]
             self.app_parameters = self.manifestjson["parameters"]
             self.app_preview_status = self.manifestjson["preview"]
-            self.app_version = self.manifestjson["version"]
+            self.app_version = self.manifestjson["manifestVersion"]
             self.appname = self.manifestjson["name"]
             self.dashboards, self.searches = self.get_content(self.appjson)
             self.remove_text_panels(self.dashboards)
@@ -56,6 +58,13 @@ class TestApp(unittest.TestCase):
         except KeyError as e:
             raise Exception("%s: InitError: Required Params %s are missing from json " % (self.appname, e))
 
+    @classmethod
+    def matchanyterms(cls, terms, text):
+        for term in terms:
+            if term in text:
+                return True
+        return False
+
     @classmethod
     def extract_queries(self, dashboards):
         log_queries = []
@@ -63,7 +72,8 @@ class TestApp(unittest.TestCase):
         for dash in dashboards:
             dash_name = dash.get("name")
             if self.is_mew_board(dash):
-                for panel in dash["rootPanel"]["panels"]:
+                panels = dash["rootPanel"]["panels"] if dash.get("rootPanel") else dash.get("panels", [])
+                for panel in panels:
                     if panel.get("panelType") == "TextPanel" or panel.get("Type") == "TextPanel":
                         continue
                     for query in panel["queries"]:
@@ -123,7 +133,7 @@ class TestApp(unittest.TestCase):
 
     @classmethod
     def is_mew_board(cls, dash):
-        return dash["type"] in ("Dashboard", "MewboardSyncDefinition")
+        return dash["type"] in ("Dashboard", "MewboardSyncDefinition", "DashboardV2SyncDefinition")
 
     @abstractmethod
     def test_is_deployable(self):
@@ -217,7 +227,7 @@ class TestApp(unittest.TestCase):
             if not self.appname in dash["name"]:
                 err.append(dash.get("name"))
         if err:
-            msg = "Following dashboards %s should follow <appname>-<dashboard title>" % ",".join(err)
+            msg = "Following dashboards %s should follow <appname> - <dashboard title>" % ",".join(err)
             self.add_warning(msg)
 
 
@@ -258,13 +268,18 @@ class TestApp(unittest.TestCase):
                 parent_dir = os.path.basename(root.strip("/"))
                 if parent_dir in ["icon", "screenshots"]:
                     self.assertTrue(filesize < self.MAX_FILE_SIZE)
-                if parent_dir in ["screenshots"]:
+                if parent_dir == "screenshots":
                     im = Image.open(filepath)
                     width, height = im.size
-                    self.assertTrue(width > 832 and height > 520, "Image dimension should be 832x520 or greater")
                     logger.info("ImageName: %s Width: %s Height: %s" % (filename, width, height))
+                    self.assertTrue(width > 832 and height > 520, "Dashboard Screenshot dimension should be 832x520 or greater")
                     if width < 1400:
                         self.add_warning("For optimal full screen size we recommend width of 1400")
+                elif parent_dir == "icon":
+                    im = Image.open(filepath)
+                    width, height = im.size
+                    logger.info("ImageName: %s Width: %s Height: %s" % (filename, width, height))
+                    self.assertTrue(width == 72 and height == 72, "App Icon dimension should be 72x72")
                 elif parent_dir == "logs":
                     self.assertTrue(filesize < 2*self.MAX_FILE_SIZE)
                 file_size_sum += filesize
@@ -274,9 +289,8 @@ class TestApp(unittest.TestCase):
     def test_uuid_matches_stored_value(self):
         op_cli = ProviderFactory.get_provider("aws")
         store = op_cli.get_storage("keyvalue", 'partner_app_ids', logger=logger)
-        repo_url = os.getenv("GIT_REPO_URL", "")
-        repo_full_name = repo_url.split("github.com" )[-1].strip("/").strip(":")
-        self.assertTrue(self.manifestjson["uuid"] == store.get(repo_full_name))
+        app_name_slug = slugify(self.appname)
+        self.assertTrue(self.manifestjson["uuid"] == store.get(app_name_slug))
 
     def check_params_in_log_query(self, query_string, location_text):
         func = lambda r, x: r or x in query_string
@@ -380,8 +394,10 @@ class TestApp(unittest.TestCase):
         dashboards = copy.deepcopy(dashboards)
         for dash in dashboards:
             if cls.is_mew_board(dash):
-                if "rootPanel" in dash and "panels" in dash["rootPanel"]:
+                if dash.get("rootPanel"):
                     dash["rootPanel"]["panels"] = sorted(dash["rootPanel"]["panels"], key=lambda x: x.get("title"))
+                elif "panels" in dash:
+                    dash["panels"] = sorted(dash["panels"], key=lambda x: x.get("title"))
             elif "panels" in dash:
                 dash["panels"] = sorted(dash["panels"], key=lambda x: x.get("name"))
 
@@ -400,7 +416,12 @@ class TestClassicDashboards(TestApp):
     def remove_text_panels(self, dashboards):
         for dash in dashboards:
             if self.is_mew_board(dash):
-                dash["rootPanel"]["panels"] = [panel for panel in dash["rootPanel"]["panels"] if not (panel["type"] in ("TextPanel"))]
+                if dash.get("rootPanel"):
+                    dash["rootPanel"]["panels"] = [panel for panel in dash["rootPanel"]["panels"] if
+                                                   not (panel["type"] in ("TextPanel"))]
+                else:
+                    dash["panels"] = [panel for panel in dash["panels"] if not (panel["type"] in ("TextPanel"))]
+
             else:
                 dash["panels"] = [panel for panel in dash["panels"] if not (panel["viewerType"] in ("title", "text"))]
 
@@ -434,19 +455,26 @@ class TestClassicDashboards(TestApp):
                          self.deployment_name, response))
 
     def test_valid_timerange(self):
+
         for dash in self.dashboards:
             if self.is_mew_board(dash):
-                for panel in dash["rootPanel"]["panels"]:
-                    self.assertTrue("timeRange" not in panel or panel["timeRange"] is None or "relative" in json.dumps(panel["timeRange"]),
+                self.assertTrue(self.matchanyterms(self.datetime_terms, json.dumps(dash["timeRange"])),
+                                "Dashboard: %s does not use relative time" % dash.get("name"))
+                panels = dash["rootPanel"]["panels"] if dash.get("rootPanel") else dash.get("panels", [])
+                for panel in panels:
+                    self.assertTrue("timeRange" not in panel or panel["timeRange"] is None or self.matchanyterms(self.datetime_terms, json.dumps(panel["timeRange"])),
                                     "Panel: %s in Dashboard: %s does not use relative time" % (
                                         panel.get("title"), dash.get("name")))
+                    if panel.get("timeRange") is not None:
+                        self.add_warning("It's recommended to use dashboard level timerange in Panel: %s in Dashboard: %s" % (panel.get("title"), dash.get("name")))
             else:
                 for panel in dash["panels"]:
-                    self.assertTrue("relative" in panel["timeRange"],
+                    self.assertTrue("timeRange" not in panel or panel["timeRange"] is None or self.matchanyterms(self.datetime_terms, json.dumps(panel["timeRange"])),
                                     "Panel: %s in Dashboard: %s does not use relative time" % (
                                     panel.get("name"), dash.get("name")))
 
-        # Todo check time range for scheduled searches
+        for search in self.searches:
+            self.assertTrue(search["defaultTimeRange"].startswith("-"), "Saved Search: %s does not use relative time " % search["name"])
 
     def test_has_scheduled_searches(self):
         for search in self.searches:
@@ -460,7 +488,14 @@ class TestClassicDashboardsV2(TestApp):
     def remove_text_panels(self, dashboards):
         for dash in dashboards:
             if self.is_mew_board(dash):
-                dash["rootPanel"]["panels"] = [panel for panel in dash["rootPanel"]["panels"] if not (panel["panelType"] in ("TextPanel"))]
+                if dash.get("rootPanel"):
+                    dash["rootPanel"]["panels"] = [panel for panel in dash["rootPanel"]["panels"] if
+                                                   not (panel["panelType"] in ("TextPanel"))]
+
+                else:
+                    dash["panels"] = [panel for panel in dash["panels"] if not (panel["panelType"] in ("TextPanel"))]
+
+
             else:
                 dash["panels"] = [panel for panel in dash["panels"] if not (panel["viewerType"] in ("title", "text"))]
 
@@ -469,7 +504,7 @@ class TestClassicDashboardsV2(TestApp):
         searches = []
         dashboards = []
         for dash in folder["children"]:
-            if dash["type"] in ("DashboardSyncDefinition", "MewboardSyncDefinition"):
+            if dash["type"] in ("DashboardSyncDefinition", "MewboardSyncDefinition", "DashboardV2SyncDefinition"):
                 dashboards.append(dash)
             elif dash["type"] == "SavedSearchWithScheduleSyncDefinition":
                 searches.append(dash)
@@ -486,18 +521,27 @@ class TestClassicDashboardsV2(TestApp):
                          self.deployment_name, response))
 
     def test_valid_timerange(self):
+
         for dash in self.dashboards:
             if self.is_mew_board(dash):
-                for panel in dash["rootPanel"]["panels"]:
-                    self.assertTrue("timeRange" not in panel or panel["timeRange"] is None or "relative" in json.dumps(panel["timeRange"]),
+                self.assertTrue(self.matchanyterms(self.datetime_terms, json.dumps(dash["timeRange"])),
+                                "Dashboard: %s does not use relative time" % dash.get("name"))
+                panels = dash["rootPanel"]["panels"] if dash.get("rootPanel") else dash.get("panels")
+                for panel in panels:
+                    self.assertTrue("timeRange" not in panel or panel["timeRange"] is None or self.matchanyterms(self.datetime_terms, json.dumps(panel["timeRange"])),
                                     "Panel: %s in Dashboard: %s does not use relative time" % (
                                         panel.get("title"), dash.get("name")))
+                    if panel.get("timeRange") is not None:
+                        self.add_warning("It's recommended to use dashboard level timerange in Panel: %s in Dashboard: %s" % (panel.get("title"), dash.get("name")))
             else:
                 for panel in dash["panels"]:
-                    timerangestr = json.dumps(panel["timeRange"])
-                    self.assertTrue("RelativeTimeRangeBoundary" in timerangestr or "CompleteLiteralTimeRange" in timerangestr, "Panel: %s in Dashboard: %s does not use relative time" % (
+                    self.assertTrue("timeRange" not in panel or panel["timeRange"] is None or self.matchanyterms(self.datetime_terms, json.dumps(panel["timeRange"])),
+                                    "Panel: %s in Dashboard: %s does not use relative time" % (
                         panel.get("name"), dash.get("name")))
-        # Todo check time range for scheduled searches
+
+        for search in self.searches:
+            self.assertTrue(search['search']["defaultTimeRange"].startswith("-"), "Saved Search: %s does not use relative time " % search["name"])
+
 
     @classmethod
     def get_saved_search_queries(self, searches):
